@@ -1,4 +1,6 @@
 import socket
+from uuid import UUID
+
 from multidict import MultiDict
 
 
@@ -12,6 +14,10 @@ def as_list(key, data):
     return data
 
 
+def as_dict(data, key="data"):
+    return {key: data} if not isinstance(data, dict) else data
+
+
 def local_ip():
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     s.connect(("8.8.8.8", 80))
@@ -25,3 +31,10 @@ def as_params(*, params=None, **kwargs):
     params = MultiDict(params if params is not None else {})
     params.update(kwargs)
     return params
+
+
+def uid(id_):
+    try:
+        return str(UUID(id_))
+    except ValueError:
+        return id_
